@@ -29,7 +29,7 @@ package Net::SSH2::Cisco;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 our @ISA;
 
 use Net::SSH2 0.51;
@@ -790,8 +790,16 @@ sub login {
             CORE::binmode ($chan)
         }
         $self->{_SSH_CHAN_} = $chan;
+
         # flush buffer, read off first prompt
-        $self->waitfor($self->{cmd_prompt});
+        if ($sent_wakeup == 0 && $self->{send_wakeup} eq 'noflush') {
+
+            # do nothing
+            $sent_wakeup = 1;
+        } else {
+            $sent_wakeup = 1;
+            $self->waitfor($self->{cmd_prompt});
+        }
     } else {
         # This is where we'd do 'timeout' send_wakeup if Net::SSH2 supported
         if ($sent_wakeup == 0 && $self->{send_wakeup} eq 'timeout') {
@@ -2537,10 +2545,11 @@ action is performed.  See C<errmode()>.
 
     $when = $obj->send_wakeup('connect');
     $when = $obj->send_wakeup('timeout');
+    $when = $obj->send_wakeup('noflush');
     $when = $obj->send_wakeup(0);
 
-This is provided only for compatibility with drop-in replacement 
-in Net::Telnet::Cisco scripts.  This has no functionality in this 
+B<Note:>  This is provided only for compatibility with drop-in replacement 
+in Net::Telnet::Cisco scripts.  This has limited functionality in this 
 module.
 
 Some routers quietly allow you to connect but don't display the
@@ -2550,6 +2559,11 @@ it spurs the routers to print something.
 The issue is a Net::SSH2::Channel to send the newline over isn't 
 opened until I<after> login.
 
+However, sometimes there is contention on who talks first.  With non-blocking 
+mode by default, if the router sends a prompt, it must be "flushed" from the 
+channel before subsequent commands can be issues to the router.  Using the 
+'noflush' argument skips this step during login.
+
 =item B<sock> - return underlying socket object
 
     $sock = $obj->sock;
@@ -2669,7 +2683,7 @@ example:
 
 TIMEOUT OCCUR!  However, non-blocking mode allows output to fill buffer 
 in the background up to a 'MORE' prompt:
-  
+
   Current configuration : 9721 bytes
   !
   upgrade fpd auto
@@ -2696,7 +2710,7 @@ yourself at a router console by trying:
   show run
   [DO NOT PRESS SPACE OR ENTER AT THE --MORE-- PROMPT]
   show version
-  
+
 Alternatively, try this, which is what C<waitfor_clear> effectively does:
 
   terminal length 24
@@ -2743,7 +2757,7 @@ If you don't know what that means visit L<http://perl.com/>.
 
 =head1 AUTHOR
 
-Copyright (C) Michael Vincent 2015
+Copyright (c) 2015 Michael Vincent
 
 L<http://www.VinsWorld.com>
 
